summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/scripting/kexiscripting/kexiscriptpart.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/scripting/kexiscripting/kexiscriptpart.h')
-rw-r--r--kexi/plugins/scripting/kexiscripting/kexiscriptpart.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kexi/plugins/scripting/kexiscripting/kexiscriptpart.h b/kexi/plugins/scripting/kexiscripting/kexiscriptpart.h
index ddba0d72..eca7a001 100644
--- a/kexi/plugins/scripting/kexiscripting/kexiscriptpart.h
+++ b/kexi/plugins/scripting/kexiscripting/kexiscriptpart.h
@@ -22,8 +22,8 @@
#ifndef KEXISCRIPTPART_H
#define KEXISCRIPTPART_H
-#include <qdom.h>
-#include <qcstring.h>
+#include <tqdom.h>
+#include <tqcstring.h>
#include <kexi.h>
#include <kexipart.h>
@@ -35,17 +35,18 @@
class KexiScriptPart : public KexiPart::Part
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
*
* \param parent The parent QObject this part is child of.
* \param name The name this part has.
* \param args Optional list of arguments passed to this part.
*/
- KexiScriptPart(QObject *parent, const char *name, const QStringList& args);
+ KexiScriptPart(TQObject *tqparent, const char *name, const TQStringList& args);
/**
* Destructor.
@@ -56,28 +57,28 @@ class KexiScriptPart : public KexiPart::Part
* Implementation of the \a KexiPart::Part::execute method used to
* execute the passed \p item instance.
*/
- virtual bool execute(KexiPart::Item* item, QObject* sender = 0);
+ virtual bool execute(KexiPart::Item* item, TQObject* sender = 0);
/**
* \return the i18n message for the passed \p englishMessage string.
*/
- virtual QString i18nMessage(const QCString& englishMessage) const;
+ virtual TQString i18nMessage(const TQCString& englishMessage) const;
protected:
/**
* Create a new view.
*
* \param parent The parent QWidget the new view is displayed in.
* \param dialog The \a KexiDialogBase the view is child of.
* \param item The \a KexiPart::Item this view is for.
* \param viewMode The viewmode we like to have a view for.
*/
- virtual KexiViewBase* createView(QWidget *parent,
+ virtual KexiViewBase* createView(TQWidget *tqparent,
KexiDialogBase* dialog,
KexiPart::Item& item,
int viewMode = Kexi::DesignViewMode,
- QMap<QString,QString>* staticObjectArgs = 0);
+ TQMap<TQString,TQString>* staticObjectArgs = 0);
/**
* Initialize the part's actions.
@@ -35,17 +35,18 @@
* Constructor.
*
- * \param parent The parent QObject this part is child of.
+ * \param tqparent The tqparent TQObject this part is child of.
* \param name The name this part has.
* \param args Optional list of arguments passed to this part.
@@ -56,28 +57,28 @@ class KexiScriptPart : public KexiPart::Part
* Create a new view.
*
- * \param parent The parent QWidget the new view is displayed in.
+ * \param tqparent The tqparent TQWidget the new view is displayed in.
* \param dialog The \a KexiDialogBase the view is child of.
* \param item The \a KexiPart::Item this view is for.